@@ -14,7 +14,7 @@
 %define LESSWRITEOPS
 ;-------
 %define UTF8				;for UTF8 console or xterm e.g. @ Suse 9.1
-%define UTF8RTS				;runtime detection of UTF8 console display
+;%define UTF8RTS				;runtime detection of UTF8 console display
 ;-------
 %define BEEP_IN_VI			;undef if you hate beeping computers
 %define USE_MATH			;undef if you don't use the numerics
