@@ -14,12 +14,16 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
+//  adapted to mipsel (fritz box fon): 2005-08 C.O. (Christian Ostheimer)
 //---------------------------------------------------------------------
 
 #ifndef __GNUC__
 #error "Sorry, but I need GNU C."
 #endif
 
+#ifndef MAX_TEXTSIZE
+ #define MAX_TEXTSIZE 10240000 // x86 pc
+#endif
 #define CURSORMGNT
 #define LESSWRITEOPS
 #ifdef LESSWRITEOPS
@@ -119,15 +123,18 @@ char asklineno[]	="^QI LINE:";
 char optiontext[]	="OPT? C/B";
 #define stdtxtlen	10
 
-char screencolors0[]={27,'[','4','0','m',27,'[','3','7','m'};
-char bold0[]={27,'[','0','m'};			// reset to b/w
-char screencolors1[]={27,'[','4',/*'4'*/'1','m',27,'[','3','3','m'}; // yellow on red /*blue*/
-char bold1[]={27,'[','1','m',27,'[','7','m'};	// bold 
+char screencolors0[]={27,'[','4','0','m',27,'[','3','7','m',27,'[','0','m'};
+// pointer pbold0 instead of array bold0[] to avoid alignment issue on mipsel
+// (content of bold0[] is now appended to screencolors0, C.O.)
+char * pbold0=screencolors0 + 10;	// reset to b/w;
+char screencolors1[]={27,'[','4',/*'4'*/'1','m',27,'[','3','3','m',27,'[','1','m',27,'[','7','m'}; // yellow on red /*blue*/
+char * pbold1=screencolors1 + 10;	// bold 
 
-#define reversevideoX bold1		// good for "linux" terminal on /dev/tty (but not xterm,kvt)
+#define preversevideoX pbold1		// good for "linux" terminal on /dev/tty (but not xterm,kvt)
 #define scolorslen	14
 #define boldlen	4			// take care length of bold0 == length of bold1
-#define O_WRONLY_CREAT_TRUNC	01101
+//#define O_WRONLY_CREAT_TRUNC	01101
+#define O_WRONLY_CREAT_TRUNC	(O_WRONLY | O_CREAT | O_TRUNC)
 #define PERMS	0644
 
 char resfile[]=LIBDIR"/e3.res";
@@ -213,7 +220,7 @@ unsigned char screenline [256+4*scolorslen];	// max possible columns + 4 color E
 
 unsigned char errmsgs [errbufsize];
 //------
-#define max	10240000
+#define max	MAX_TEXTSIZE
 unsigned char text [max];
 #define sot	(text+1)		// start-of-text
 
@@ -224,7 +231,8 @@ long stack[100];
 #define RETURN	goto *(*esp--)
 #define CALL(calladr,retadr) *++esp=(long)&&_loc##retadr; goto calladr; _loc##retadr:
 #define PUSH(arg) *++esp=arg
-#define POP(arg) (long*)arg=*esp--
+//#define POP(arg) (long*)arg=*esp--
+#define POP(arg) arg=(long *)(*esp--);
 
 int main(int argc,char**argv,char **envp)
 {
@@ -792,13 +800,13 @@ SetInverseStatus:PUSH(ecx);		// returns zero flag
 	 goto SIS4;
 	}
 	inverse = 1;
-	esi = (long)&reversevideoX;
+	esi = (long)preversevideoX;
 	esi+=revvoff;			// switch between esc seq for linux or Xterm
 	goto SIS2;
 SIS1:	if (inverse-1) goto SIS3;
 	inverse = 0;
 SIS6:	isbold = 0;
-SIS5:	esi = (long)&bold0;
+SIS5:	esi = (long)pbold0;
 SIS2:	ecx = boldlen;
 	do {
 	*(unsigned char*)edi++=*(unsigned char*)esi++;
@@ -814,7 +822,7 @@ SetColor:PUSH(ecx);			// expects extra-flag:bold  else normal
 	if (!extra) goto SCEsc1;
 	if (isbold==1) goto SIS4;	// never set bold if it is already bold
 	isbold = 1;
-SCEsc2:	esi = (long)&bold1;
+SCEsc2:	esi = (long)pbold1;
 	goto SIS2;
 SCEsc1:	if (!isbold) goto SIS4;		// ditto
 	goto SIS6;
@@ -1296,7 +1304,8 @@ SpaceAva:PUSH(edi);
 Ins0:	POP(edi);			// here is the jmp destination from DeleteByte
 //------
 	changed = CHANGED;
-	(long)ebp+=eax;
+//	(long)ebp+=eax;
+	ebp=(void *)((long)ebp+eax);
 	if ((unsigned long)edi>=(unsigned long)blockende) goto Ins1;
 	blockende+=eax;
 Ins1:	if ((unsigned long)edi>=(unsigned long)blockbegin) goto Ins2;
